@@ -2,7 +2,6 @@ from pydantic import BaseModel, Extra
 from nonebot import get_driver
 from nonebot.log import logger
 import yaml
-import json
 from pathlib import Path
 
 
@@ -11,6 +10,7 @@ class Config(BaseModel, extra=Extra.ignore):
     NG_CONFIG_PATH: str = "config/naturel_gpt_config.yml"
     NG_DEV_MODE: bool = False
 
+
 driver = get_driver()
 global_config = driver.config
 config = Config.parse_obj(global_config)
@@ -23,9 +23,9 @@ CONFIG_TEMPLATE = {
     ],
     "PRESETS": {
         "白羽": {
-            'bot_name': '白羽', # 人格名称
+            'bot_name': '白羽',  # 人格名称
             'is_locked': True,  # 是否锁定人格，锁定后无法编辑人格
-            'is_default': True, # 是否为默认人格
+            'is_default': True,  # 是否为默认人格
             'bot_self_introl': '白羽是一名喜欢二次元的中二宅女，她机智、傲娇，对人类充满好奇，习惯以白羽喵自称，聊天时喜欢使用各种可爱的颜文字，如果冒犯到她会生气。',
         },
         "浅枫": {
@@ -54,27 +54,28 @@ CONFIG_TEMPLATE = {
     'CHAT_TEMPERATURE': 0.6,    # 温度越高越随机
     'CHAT_FREQUENCY_PENALTY': 0.6,  # 频率惩罚
     'CHAT_PRESENCE_PENALTY': 0.6,   # 出现惩罚
-    'REQ_MAX_TOKENS': 2048, # 单次请求最大token数
+    'REQ_MAX_TOKENS': 2048,  # 单次请求最大token数
     'REPLY_MAX_TOKENS': 1024,   # 单次回复最大token数
     'CHAT_MAX_SUMMARY_TOKENS': 512,   # 单次总结最大token数
 
     'REPLY_ON_NAME_MENTION': True,  # 是否在被提及时回复
     'REPLY_ON_AT': True,            # 是否在被at时回复
 
-    'USER_MEMORY_SUMMARY_THRESHOLD': 12, # 用户记忆阈值
+    'USER_MEMORY_SUMMARY_THRESHOLD': 12,  # 用户记忆阈值
 
+    'CHAT_ENABLE_SUMMARY_CHAT': False,   # 是否启用总结对话
     'CHAT_MEMORY_SHORT_LENGTH': 8,  # 短期对话记忆长度
-    'CHAT_MEMORY_MAX_LENGTH': 12,   # 长期对话记忆长度
-    'CHAT_SUMMARY_INTERVAL': 10, # 长期对话记忆间隔
+    'CHAT_MEMORY_MAX_LENGTH': 16,   # 长期对话记忆长度
+    'CHAT_SUMMARY_INTERVAL': 10,  # 长期对话记忆间隔
 
-    'NG_DATA_PATH': "./data/naturel_gpt/", # 数据文件目录
-    'NG_EXT_PATH': "./data/naturel_gpt/extensions/", # 拓展目录
+    'NG_DATA_PATH': "./data/naturel_gpt/",  # 数据文件目录
+    'NG_EXT_PATH': "./data/naturel_gpt/extensions/",  # 拓展目录
 
-    'ADMIN_USERID': ['填写管理员QQ号'], # 管理员QQ号
+    'ADMIN_USERID': ['填写管理员QQ号'],  # 管理员QQ号
     'FORBIDDEN_USERS': ['123456'],   # 拒绝回应的QQ号
 
-    'WORD_FOR_WAKE_UP': [], # 自定义触发词
-    'WORD_FOR_FORBIDDEN': [], # 自定义禁止触发词
+    'WORD_FOR_WAKE_UP': [],  # 自定义触发词
+    'WORD_FOR_FORBIDDEN': [],  # 自定义禁止触发词
 
     'RANDOM_CHAT_PROBABILITY': 0,   # 随机聊天概率
 
@@ -85,13 +86,15 @@ CONFIG_TEMPLATE = {
     'NG_MAX_RESPONSE_PER_MSG': 5,  # 每条消息最大响应次数
     'NG_ENABLE_MSG_SPLIT': True,   # 是否启用消息分割
 
+    'OPENAI_PROXY_SERVER': '',  # 请求OpenAI的代理服务器
+
     'NG_EXT_LOAD_LIST': [{
         'EXT_NAME': 'ext_random',
         'IS_ACTIVE': False,
         'EXT_CONFIG': {},
     }],     # 加载的拓展列表
 
-    '__DEBUG__': False, # 是否启用debug模式
+    '__DEBUG__': False,  # 是否启用debug模式
 }
 
 config_path = config.NG_CONFIG_PATH
@@ -100,7 +103,7 @@ config_path = config.NG_CONFIG_PATH
 if not Path("config").exists():
     Path("config").mkdir()
 
-if config.NG_DEV_MODE: # 开发模式下不读取原配置文件，直接使用模板覆盖原配置文件
+if config.NG_DEV_MODE:  # 开发模式下不读取原配置文件，直接使用模板覆盖原配置文件
     with open(config_path, 'w', encoding='utf-8') as f:
         yaml.dump(CONFIG_TEMPLATE, f, allow_unicode=True)
 
